# openai-translator-agent
A simple demonstration of Open AI Agent framework to perform translations

> [!IMPORTANT]  
> You will need to create a .env file and populate it with the following environment variables:
- OPENAI_API_KEY